@@ -18,6 +18,15 @@ try:
     import random
     from pathlib import Path
     from typing import (Tuple , Any)
+    from .Exceptions import (
+        AdminPermissionRequestDenied ,
+        InvalidVariableType ,
+        NoneTypeArgumentBool ,
+        NoneTypeArgumentInt ,
+        NoneTypeArgumentString ,
+        UndefinedOperatingSystem ,
+        UnrecognizeableTypeArgument
+    )
     
     if (__name__ == '__main__' and __package__ is None):
         sys.path.append(os.path.dirname(p=os.path.dirname(p=os.path.abspath(path=__file__))))
@@ -40,7 +49,7 @@ except:
 class Version:
     """with io.open(file=os.path.join(os.path.abspath('.') , 'version.txt') , mode='r+' , encoding='utf-8' , errors=None) as v:
         __version__ = v.readline()"""
-    __version__ = '4.2.5'
+    __version__ = '4.2.6'
 
 
 
@@ -54,21 +63,21 @@ class OperatingSystem(object):
 
 
 
-class PSTExceptions:
-    class AdminPermissionRequestDenied(Exception):
-        """ Set the Argument Variable 'show' to 'True' """
-    class NoneTypeArgumentBool(Exception):
-        """ The Variable For Argument 'show' Should be 'Boolean' Type """
-    class NoneTypeArgumentInt(Exception):
-        """ The Variable For Argument 'timeout' Should be 'Int' Type """
-    class NoneTypeArgumentString(Exception):
-        """ The Variable For Argument 'link' Should be 'String' Type """
-    class UndefinedOperatingSystem(Exception):
-        """ The Operating System is Not Defined Yet """
-    class UnrecognizeableTypeArgument(Exception):
-        """ The Variable For Arguments is not Recognizeable """
-    class InvalidVariableType(Exception):
-        """ The Variable Type Chosen is not The Correct One """
+# class PSTExceptions:
+#     class AdminPermissionRequestDenied(Exception):
+#         """ Set the Argument Variable 'show' to 'True' """
+#     class NoneTypeArgumentBool(Exception):
+#         """ The Variable For Argument 'show' Should be 'Boolean' Type """
+#     class NoneTypeArgumentInt(Exception):
+#         """ The Variable For Argument 'timeout' Should be 'Int' Type """
+#     class NoneTypeArgumentString(Exception):
+#         """ The Variable For Argument 'link' Should be 'String' Type """
+#     class UndefinedOperatingSystem(Exception):
+#         """ The Operating System is Not Defined Yet """
+#     class UnrecognizeableTypeArgument(Exception):
+#         """ The Variable For Arguments is not Recognizeable """
+#     class InvalidVariableType(Exception):
+#         """ The Variable Type Chosen is not The Correct One """
         
         
 
@@ -165,11 +174,11 @@ class NetworkTools:
             if (show is True):
                 return cls.localIP
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowPublicIP(cls , show : bool = False) -> str:
@@ -188,11 +197,11 @@ class NetworkTools:
                 except ConnectionError:
                     pass
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowMacAddress(cls , show : bool = False , network_request : bool = True) -> str:
@@ -212,11 +221,11 @@ class NetworkTools:
                 except ConnectionError:
                     pass
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowNetworkInfo(cls , show : bool = False) -> str:
@@ -242,11 +251,11 @@ class NetworkTools:
                             print(f"Netmask : {address.netmask}")
                             print(f"Broadcast MAC : {address.broadcast}")
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowSavedNetworks(cls , show : bool = False) -> str:
@@ -270,14 +279,14 @@ class NetworkTools:
                 else:
                     return f"{colorama.ansi.Fore.YELLOW}This Method Only Works on Windows OS !!!"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             elif (show is None):
                 show = None
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.AdminPermissionRequestDenied
+            return AdminPermissionRequestDenied
 
     @classmethod
     def TestConnection(cls , show : bool = False , timeout : int = 5):
@@ -299,13 +308,13 @@ class NetworkTools:
                     except (requests.ConnectionError , requests.Timeout) as E:
                         return f"{colorama.ansi.Fore.RED}You're not Connected To Internet \n{E}"
                 else:
-                    return PSTExceptions.NoneTypeArgumentInt
+                    return NoneTypeArgumentInt
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def StatusCodeChecker(cls , show : bool = False , link : str = ''):
@@ -327,13 +336,13 @@ class NetworkTools:
                         else:
                             print(f"{colorama.ansi.Fore.MAGENTA}Status : {colorama.ansi.Fore.BLUE}{code} {colorama.ansi.Fore.RED}is not Available")
                 else:
-                    return PSTExceptions.NoneTypeArgumentString
+                    return NoneTypeArgumentString
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -359,9 +368,9 @@ class CPUTools:
         if (show is True):
             return cls.cpuType
         elif (show is False):
-            return PSTExceptions.AdminPermissionRequestDenied
+            return AdminPermissionRequestDenied
         else:
-            return PSTExceptions.UnrecognizeableTypeArgument
+            return UnrecognizeableTypeArgument
 
     @classmethod
     def ShowCPUPhysicalCores(cls , show : bool = False) -> int:
@@ -377,11 +386,11 @@ class CPUTools:
             if (show is True):
                 return cls.phCores
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowCPUTotalCores(cls , show : bool = False) -> str:
@@ -397,11 +406,11 @@ class CPUTools:
             if (show is True):
                 return cls.totCores
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowCPUMaxFreq(cls , show : bool = False) -> float:
@@ -417,11 +426,11 @@ class CPUTools:
             if (show is True):
                 return f"{cls.cpuFreq.max:.2f}Mhz"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
     
     @classmethod
     def ShowCPUMinFreq(cls , show : bool = False) -> float:
@@ -437,11 +446,11 @@ class CPUTools:
             if (show is True):
                 return f"{cls.cpuFreq.min:.2f}Mhz"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowCPUCurrentFreq(cls , show : bool = False) -> float:
@@ -457,11 +466,11 @@ class CPUTools:
             if (show is True):
                 return f"{cls.cpuFreq.current:.2f}Mhz"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowCPUTotalUsage(cls , show : bool = False) -> float:
@@ -477,11 +486,11 @@ class CPUTools:
             if (show is True):
                 return f"{psutil.cpu_percent()}%"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowCPUUsagePerCore(cls , show : bool = False) -> str:
@@ -498,11 +507,11 @@ class CPUTools:
                 for core , percentage in enumerate(psutil.cpu_percent(percpu = True , interval = 1)):
                     print(f"Core {core} : {percentage}%")
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -528,11 +537,11 @@ class GPUTools:
                     gpuID = gpu.id
                 return gpuID
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPUName(cls , show : bool = False) -> str:
@@ -550,11 +559,11 @@ class GPUTools:
                     gpuName = gpu.name
                 return gpuName
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPULoad(cls , show : bool = False) -> float:
@@ -577,11 +586,11 @@ class GPUTools:
                         newGpu = f"{colorama.ansi.Fore.GREEN}{gpu.load * 100}%{colorama.ansi.Fore.WHITE}"
                         return newGpu
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPUFreeMemory(cls , show : bool = False) -> float:
@@ -599,11 +608,11 @@ class GPUTools:
                     gpuFree = gpu.memoryFree
                 return gpuFree
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPUUsedMemory(cls , show : bool = False) -> float:
@@ -621,11 +630,11 @@ class GPUTools:
                     gpuUsed = f"{gpu.memoryUsed}MB"
                 return gpuUsed
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPUTotalMemory(cls , show : bool = False) -> float:
@@ -643,11 +652,11 @@ class GPUTools:
                     gpuTot = f"{gpu.memoryTotal}MB"
                 return gpuTot
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPUTemperature(cls , show : bool = False) -> float:
@@ -665,11 +674,11 @@ class GPUTools:
                     gpuTemp = f"{gpu.temperature}℃"
                 return gpuTemp
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowGPU_UUID(cls , show : bool = False) -> str:
@@ -687,11 +696,11 @@ class GPUTools:
                     gpuUUID = gpu.uuid
                 return gpuUUID
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -715,11 +724,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.total)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowAvailableRAM(cls , show : bool = False) -> float:
@@ -735,11 +744,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.available)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowUsedRAM(cls , show : bool = False) -> float:
@@ -755,11 +764,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.used)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowRAMPercentage(cls , show : bool = False) -> float:
@@ -775,11 +784,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.percent)}%"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowTotalSwap(cls , show : bool = False) -> float:
@@ -795,11 +804,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.total)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowFreeSwap(cls , show : bool = False) -> int:
@@ -815,11 +824,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.free)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowUsedSwap(cls , show : bool = False) -> float:
@@ -835,11 +844,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.used)}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowSwapPercentage(cls , show : bool = False) -> float:
@@ -855,11 +864,11 @@ class RAMTools:
             if (show is True):
                 return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.percent)}%"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -890,11 +899,11 @@ class DiskTools:
                     cls.bitMask >>= 1
                 return cls.listDrives
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowParentDiskTotalMemory(cls , show : bool = False) -> float:
@@ -910,11 +919,11 @@ class DiskTools:
             if (show is True):
                 return cls.parentDiskInfo.total / 1024 ** 3
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod    
     def ShowParentDiskUsedMemory(cls , show : bool = False) -> float:
@@ -930,11 +939,11 @@ class DiskTools:
             if (show is True):
                 return cls.parentDiskInfo.used / 1024 ** 3
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod    
     def ShowParentDiskFreeMemory(cls , show : bool = False) -> float:
@@ -950,11 +959,11 @@ class DiskTools:
             if (show is True):
                 return cls.parentDiskInfo.free / 1024 ** 3
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod    
     def ShowParentDiskPercentage(cls , show : bool = False) -> float:
@@ -970,11 +979,11 @@ class DiskTools:
             if (show is True):
                 return f"{cls.parentDiskInfo.percent:.2f}"
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod    
     def ShowDiskInfo(cls , show : bool = False) -> str:
@@ -1001,11 +1010,11 @@ class DiskTools:
                     print(f"Free : {PSTValidators.LengthValidator.getSize(partitionUsage.free)}")
                     print(f"Percentage : {PSTValidators.LengthValidator.getSize(partitionUsage.percent)}\n")
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -1044,11 +1053,11 @@ class SystemTools:
             if (show is True):
                 return cls.osName
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowOsType(cls , show : bool = False) -> str:
@@ -1064,11 +1073,11 @@ class SystemTools:
             if (show is True):
                 return cls.osType
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowNodeName(cls , show : bool = False) -> str:
@@ -1084,11 +1093,11 @@ class SystemTools:
             if (show is True):
                 return cls.nodeName
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowOSRelease(cls , show : bool = False) -> str:
@@ -1104,11 +1113,11 @@ class SystemTools:
             if (show is True):
                 return cls.sysRelease
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowOSVersion(cls , show : bool = False) -> str:
@@ -1124,11 +1133,11 @@ class SystemTools:
             if (show is True):
                 return cls.sysVersion
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowSystemName(cls , show : bool = False) -> str:
@@ -1144,11 +1153,11 @@ class SystemTools:
             if (show is True):
                 return cls.systemName
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowSystemUptime(cls , show : bool = False) -> str:
@@ -1164,11 +1173,11 @@ class SystemTools:
             if (show is True):
                 return cls.uptimeSystem
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowUserName(cls , show : bool = False) -> str:
@@ -1184,11 +1193,11 @@ class SystemTools:
             if (show is True):
                 return cls.userName
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowSystemInformation(cls , show : bool = False , os_name : str = "Windows") -> str:
@@ -1225,15 +1234,15 @@ class SystemTools:
                             f"\n{colorama.ansi.Fore.GREEN}User Logined As : {colorama.ansi.Fore.WHITE}{cls.userName}"
                         )
                     else:
-                        return PSTExceptions.UndefinedOperatingSystem
+                        return UndefinedOperatingSystem
                 else:
-                    return PSTExceptions.InvalidVariableType
+                    return InvalidVariableType
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                PSTExceptions.UnrecognizeableTypeArgument
+                UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowPythonVersion(cls , show : bool = False) -> str:
@@ -1249,11 +1258,11 @@ class SystemTools:
             if (show is True):
                 return cls.pythonVer
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def ShowBootTime(cls , show : bool = False) -> str:
@@ -1269,11 +1278,11 @@ class SystemTools:
             if (show is True):
                 return cls.bootTime
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
@@ -1312,11 +1321,11 @@ class OtherTools:
                     )
                     return cls.configuration
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
     @classmethod
     def IsPath(cls , show : bool = False , pathaddr : str = '') -> str:
@@ -1337,13 +1346,13 @@ class OtherTools:
                     else:
                         return f"{colorama.ansi.Fore.RED}The Path Doesn't Exist\nThe Code Output is {colorama.ansi.Fore.BLUE}{False}"
                 else:
-                    return PSTExceptions.InvalidVariableType
+                    return InvalidVariableType
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
         
     @classmethod
     def GetAbsOutput(cls , show : bool = False , string : str = '') -> str:
@@ -1361,13 +1370,13 @@ class OtherTools:
                 if (PSTValidators.StringValidator.is_string(string)):
                     return eval(string)
                 else:
-                    return PSTExceptions.InvalidVariableType
+                    return InvalidVariableType
             elif (show is False):
-                return PSTExceptions.AdminPermissionRequestDenied
+                return AdminPermissionRequestDenied
             else:
-                return PSTExceptions.UnrecognizeableTypeArgument
+                return UnrecognizeableTypeArgument
         else:
-            return PSTExceptions.NoneTypeArgumentBool
+            return NoneTypeArgumentBool
 
 
 
